closest: Find the closest match in another vector

View source: R/data_transformation.R

closestR Documentation

Find the closest match in another vector

Description

Find the closest match in another vector

Usage

closest(x, table)

Arguments

x

The element vector to look up.

table

The vector of elements in which to find the closest match.

Value

The element from table that is closest in least absolute terms in x.


stuart-morrison/sumo documentation built on Jan. 2, 2025, 8:45 p.m.