dice_roller: Dice roll simulator

View source: R/numbers.R

dice_rollerR Documentation

Dice roll simulator

Description

Dice roll simulator

Usage

dice_roller(sides = 6, times = 1, dice = 1)

Arguments

sides

An integer on each of the dice.

times

An integer on how many times to roll the dice.

dice

An integer on the number of dice to roll

Value

A list of vectors for each of the dice that have been rolled.


stuart-morrison/sumo documentation built on Jan. 2, 2025, 8:45 p.m.