feature_selection_two: Dividing features to create vectors with signal in the second...

View source: R/feature_selection_two.R

feature_selection_twoR Documentation

Dividing features to create vectors with signal in the second omic

Description

Dividing features to create vectors with signal in the second omic

Usage

feature_selection_two(n_features_two, num.factor, no_factor)

Arguments

n_features_two

number of features of second omic

num.factor

type of factors - single or multiple

no_factor

number of factors


SUMO documentation built on June 8, 2025, 12:45 p.m.