View source: R/data_transformation.R
| len_uni | R Documentation |
Number of unique elements in the vector
len_uni(x)
x |
The vector to find the number of unique elements over. |
An integer of the number of unique elements in x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.