View source: R/data_transformation.R
| closest | R Documentation |
Find the closest match in another vector
closest(x, table)
x |
The element vector to look up. |
table |
The vector of elements in which to find the closest match. |
The element from table that is closest in least absolute terms in x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.