| dice_roller | R Documentation |
Dice roll simulator
dice_roller(sides = 6, times = 1, dice = 1)
sides |
An integer on each of the dice. |
times |
An integer on how many times to roll the dice. |
dice |
An integer on the number of dice to roll |
A list of vectors for each of the dice that have been rolled.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.